@@ -89,11 +89,11 @@ def _check_unsafe_url( insecure: bool, url: urllib.parse.ParseResult ) -> Tuple[
         netloc = f'{url.username}@' if url.username else ''
 
     # Create secure url
-    params = '&'.join('%s=%s' % (k,v) for k,v in params.items())
-    params = f"project={prjname}&schema={schema}&{params}"
+    params.update(project=prjname, schema=schema)
     if database:
-        params = f"{params}&dbname={database}"
+        params.update(dbname=database)
 
+    params = '&'.join('%s=%s' % (k,v) for k,v in params.items())
     urlstr = f"postgresql://{netloc}/?{params}"
 
     try:
@@ -126,7 +126,13 @@ class PostgresProtocolHandler:
         cnf = componentmanager.get_service('@3liz.org/config-service;1')
         self._insecure = cnf.getboolean('projects.cache','insecure', fallback=False)
 
-    def get_project( self, url: Optional[urllib.parse.ParseResult], strict: Optional[bool]=None,
+    def get_modified_time( self, url: urllib.parse.ParseResult) -> datetime:
+        """ Return the modified date time of the project referenced by its url
+        """
+        _, modified_time = _check_unsafe_url( self._insecure, url )
+        return modified_time
+
+    def get_project( self, url: Optional[urllib.parse.ParseResult],
                      project: Optional[QgsProject]=None,
                      timestamp: Optional[datetime]=None) -> Tuple[QgsProject, datetime]:
         """ Create or return a project
@@ -145,7 +151,7 @@ class PostgresProtocolHandler:
 
         if timestamp is None or timestamp < modified_time:
             cachemngr = componentmanager.get_service('@3liz.org/cache-manager;1')
-            project   = cachemngr.read_project(urlstr, strict=strict)
+            project   = cachemngr.read_project(urlstr)
             timestamp = modified_time
 
         return project, timestamp
